==> 0.0.2.tar.gz: lib/components/senior_bottom_navigation_bar.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

abstract class SeniorBottomNavigationBarTheme {
  static Color getSelectedItemColor({required Brightness theme}) {
    return SeniorColors.primaryColor;
  }

  static Color getUnselectedItemColor({required Brightness theme}) {
    return SeniorColors.neutralColor500;
  }
}

class SeniorBottomNavigationBarItem {
  final IconData icon;
  final IconData? activeIcon;
  final String label;

  SeniorBottomNavigationBarItem(
      {required this.icon, this.activeIcon, required this.label});
}

class SeniorBottomNavigationBar extends StatelessWidget {
  final List<SeniorBottomNavigationBarItem> items;
  final Function(int item) onTap;
  final int currentIndex;

  SeniorBottomNavigationBar({
    required Key key,
    required this.items,
    required this.onTap,
    required this.currentIndex,
  }) : super(key: key);

  List<BottomNavigationBarItem> _getBottomNavBarItems() {
    List<BottomNavigationBarItem> bottomNavItems = [];

    this.items.forEach((item) {
      bottomNavItems.add(
        BottomNavigationBarItem(
          icon: FaIcon(item.icon),
          activeIcon: FaIcon(item.activeIcon ?? item.icon),
          label: item.label,
          backgroundColor: SeniorColors.pureWhite,
        ),
      );
    });

    return bottomNavItems;
  }

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return SizedBox(
      child: BottomNavigationBar(
        key: this.key,
        type: BottomNavigationBarType.fixed,
        items: this._getBottomNavBarItems(),
        currentIndex: this.currentIndex,
        iconSize: SeniorTypographyIconSize.h4,
        showSelectedLabels: true,
        selectedLabelStyle: SeniorTypography.getTextStyle(
          token: SeniorTypographyTokens.small,
          color: SeniorBottomNavigationBarTheme.getSelectedItemColor(theme: theme),
        ),
        selectedItemColor: SeniorBottomNavigationBarTheme.getSelectedItemColor(theme: theme),
        showUnselectedLabels: true,
        unselectedLabelStyle: SeniorTypography.getTextStyle(
          token: SeniorTypographyTokens.small,
          color: SeniorBottomNavigationBarTheme.getUnselectedItemColor(theme: theme),
        ),
        unselectedItemColor: SeniorBottomNavigationBarTheme.getUnselectedItemColor(theme: theme),
        onTap: this.onTap,
      ),
      height: 56.0,
    );
  }
}

==> 0.2.0.tar.gz: lib/components/senior_bottom_navigation_bar.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorBottomNavigationBarTheme {
  SeniorBottomNavigationBarTheme._();

  static Color getSelectedItemColor({required Brightness theme}) {
    return SeniorColors.primaryColor;
  }

  static Color getUnselectedItemColor({required Brightness theme}) {
    return SeniorColors.neutralColor500;
  }
}

class SeniorBottomNavigationBarItem {
  final IconData icon;
  final IconData? activeIcon;
  final String label;

  const SeniorBottomNavigationBarItem({
    required this.icon,
    this.activeIcon,
    required this.label,
  });
}

class SeniorBottomNavigationBar extends StatelessWidget {
  final List<SeniorBottomNavigationBarItem> items;
  final Function(int) onTap;
  final int currentIndex;

  const SeniorBottomNavigationBar({
    Key? key,
    required this.items,
    required this.onTap,
    required this.currentIndex,
  }) : super(key: key);

  List<BottomNavigationBarItem> _getBottomNavBarItems() {
    List<BottomNavigationBarItem> bottomNavItems = [];

    this.items.forEach((item) {
      bottomNavItems.add(
        BottomNavigationBarItem(
          icon: FaIcon(item.icon),
          activeIcon: FaIcon(item.activeIcon ?? item.icon),
          label: item.label,
          backgroundColor: SeniorColors.pureWhite,
        ),
      );
    });

    return bottomNavItems;
  }

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return SizedBox(
      child: BottomNavigationBar(
        key: this.key,
        type: BottomNavigationBarType.fixed,
        items: this._getBottomNavBarItems(),
        currentIndex: this.currentIndex,
        iconSize: SeniorTypographyIconSize.h4,
        showSelectedLabels: true,
        selectedLabelStyle: SeniorTypography.getTextStyle(
          token: SeniorTypographyTokens.small,
          color: SeniorBottomNavigationBarTheme.getSelectedItemColor(theme: theme),
        ),
        selectedItemColor: SeniorBottomNavigationBarTheme.getSelectedItemColor(theme: theme),
        showUnselectedLabels: true,
        unselectedLabelStyle: SeniorTypography.getTextStyle(
          token: SeniorTypographyTokens.small,
          color: SeniorBottomNavigationBarTheme.getUnselectedItemColor(theme: theme),
        ),
        unselectedItemColor: SeniorBottomNavigationBarTheme.getUnselectedItemColor(theme: theme),
        onTap: this.onTap,
      ),
      height: 56.0,
    );
  }
}
